@@ -1,11 +1,11 @@
 package Test::Mock::Time;
-use 5.010001;
+use 5.008001;
 use warnings;
 use strict;
 use utf8;
 use Carp;
 
-our $VERSION = 'v0.1.6';
+our $VERSION = 'v0.1.7';
 
 use Export::Attrs;
 use List::Util qw( any );
@@ -92,9 +92,10 @@ sub ff :Export(:DEFAULT) {
     goto &ff;
 }
 
+{
+my $next_id = 0;
 sub _add_timer {
     my ($loop, $after, $repeat, $cb, $watcher) = @_;
-    state $next_id = 0;
     my $id = sprintf 'fake_%05d', $next_id++;
     push @Timers, {
         id      => $id,
@@ -110,6 +111,7 @@ sub _add_timer {
     }
     return $id;
 }
+}
 
 sub _start_timer {
     my ($watcher) = @_;
@@ -137,11 +139,11 @@ sub _mock_core_global {
         return int($Absolute + $Relative);
     });
     $Module{'CORE::GLOBAL'}->mock(localtime => sub (;$) {
-        my $time = $_[0] // int($Absolute + $Relative);
+        my $time = defined $_[0] ? $_[0] : int($Absolute + $Relative);
         return CORE::localtime($time);
     });
     $Module{'CORE::GLOBAL'}->mock(gmtime => sub (;$) {
-        my $time = $_[0] // int($Absolute + $Relative);
+        my $time = defined $_[0] ? $_[0] : int($Absolute + $Relative);
         return CORE::gmtime($time);
     });
     $Module{'CORE::GLOBAL'}->mock(sleep => sub ($) {
@@ -341,7 +343,9 @@ sub _mock_ev { ## no critic (ProhibitExcessComplexity)
     });
     $Module{'EV::Timer'}->mock(set => sub {
         my ($w, $after, $repeat) = @_;
-        $repeat //= 0;
+        if (!defined $repeat) {
+            $repeat = 0;
+        }
         my ($timer) = grep { $_->{watcher} && $_->{watcher} eq $w } @Timers, @Timers_ns;
         if ($timer) {
             $timer->{start} = $Relative;
@@ -366,7 +370,7 @@ sub _mock_ev { ## no critic (ProhibitExcessComplexity)
         my ($active) = grep { $_->{watcher} && $_->{watcher} eq $w } @Timers;
         my ($inactive) = grep { $_->{watcher} && $_->{watcher} eq $w } @Timers_ns;
         if ($active) {
-            $active->{repeat} = sprintf '%.6f', $repeat // $active->{repeat};
+            $active->{repeat} = sprintf '%.6f', defined $repeat ? $repeat : $active->{repeat};
             if ($active->{repeat} > 0) {
                 $active->{after} = $active->{repeat};
                 $active->{start} = $Relative;
@@ -376,7 +380,7 @@ sub _mock_ev { ## no critic (ProhibitExcessComplexity)
             }
         }
         elsif ($inactive) {
-            $inactive->{repeat} = sprintf '%.6f', $repeat // $inactive->{repeat};
+            $inactive->{repeat} = sprintf '%.6f', defined $repeat ? $repeat : $inactive->{repeat};
             if ($inactive->{repeat} > 0) {
                 $inactive->{after} = $inactive->{repeat};
                 $inactive->{start} = $Relative;
@@ -503,7 +507,7 @@ Test::Mock::Time - Deterministic time & timers for event loop tests
 
 =head1 VERSION
 
-This document describes Test::Mock::Time version v0.1.6
+This document describes Test::Mock::Time version v0.1.7
 
 
 =head1 SYNOPSIS
